Delimiter

Enum Delimiter 

pub enum Delimiter {
    Brace,
    Bang,
    Percent,
    Quest,
    Hash,
}
An expression delimiter.

Variants



Brace

{{ }} escaped render.



Bang

{! !} unescaped render.



Percent

{% %} escaped render using std::fmt::Display.



Quest

{? ?} escaped render using std::fmt::Debug.



Hash

{# #} unused, same as Delimiter::Brace.

Implementations

Source

impl Delimiter

pub fn match_open(ch: u8) -> Option<Self>

Returns Some if given byte considered as opening delimiter.

pub fn match_close(ch: u8) -> Option<Self>

Returns Some if given byte considered as closing delimiter.